/*
 * Vocoder
 *  2007-2012 Achim Settelmeier <vocoder@m1.sirlab.de>
 *
 */

// Includes
#include <getopt.h>
#include <stdlib.h>
#include <iostream>
#include "options.h"
#include "engine.h"

using std::cout;
using std::cerr;
using std::endl;

void initOptions(options_t &o){
	o.outputFile="output.wav";
	o.fps=44100;
	o.volume=1.0;
}

void printUsage(){
	cout << "usage: vocode -f <file> -c <file> [-o <file>] [ -v <volume> ]" << endl;
	cout << "   -f <file>  name of input formant WAV file" << endl;
	cout << "   -c <file>  name of input carrier WAV file" << endl;
	cout << "   -o <file>  name of output WAV file" << endl;
	cout << "   -v <vol>   output volume in percent, eg. -v 50 (=50%) or -v 180 (=180%)" << endl;
}

void processCommandLineArguments(options_t &o,
				 int argc,
				 char **argv){
	int opt;
	
	while((opt=getopt(argc, argv, "hf:c:o:v:"))!=-1){
		switch(opt){
		case 'f':
			o.formantFile=optarg;
			break;
		case 'c':
			o.carrierFile=optarg;
			break;
		case 'o':
			o.outputFile=optarg;
			break;
		case 'v':
			o.volume=atoi(optarg)/100.0;
			break;
		case 'h':
			printUsage();
			exit(0);
		default:
			cerr << "try vocoder -h for help." << endl;
			exit(1);
		}
	}
	
	if(o.formantFile.empty()){
		cerr << "no formant file given, aborting." << endl;
		cerr << "try vocoder -h for help." << endl;
		exit(1);
	}else if(o.carrierFile.empty()){
		cerr << "no carrier file given, aborting." << endl;
		cerr << "try vocoder -h for help." << endl;
		exit(1);
	}
}


// main
int main(int argc, char **argv){
	options_t options;
	initOptions(options);
	processCommandLineArguments(options, argc, argv);
	
	cout << "D " << "input (formant): " << options.formantFile << endl;
	cout << "D " << "input (carrier): " << options.carrierFile << endl;
	cout << "D " << "output: " << options.outputFile << endl;
	
	Engine e(options);
	e.run();
	
	return 0;
}
